@@ -13,16 +13,26 @@ PyGPSClient - Main tkinter application class.
 - Maintains central dictionary of current key navigation data as
   `gnss_status`, for use by user-selectable widgets.
 
+Global logging configuration is defined in __main__.py. To enable module
+logging, this and other subsidiary modules can use:
+
+```self.logger = logging.getLogger(__name__)```
+
+To override individual module loglevel, use e.g.
+
+```self.logger.setLevel(INFO)```
+
 Created on 12 Sep 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
 # pylint: disable=too-many-ancestors, no-member
 
-from datetime import datetime, timedelta
+import logging
+from datetime import datetime, timedelta, timezone
 from os import getenv, path
 from pathlib import Path
 from queue import Empty, Queue
@@ -32,7 +42,10 @@ from tkinter import E, Frame, N, PhotoImage, S, TclError, Tk, Toplevel, W, font
 
 from pygnssutils import GNSSMQTTClient, GNSSNTRIPClient, MQTTMessage
 from pygnssutils.socket_server import ClientHandler, SocketServer
-from pyubx2 import NMEA_PROTOCOL, RTCM3_PROTOCOL, UBX_PROTOCOL, protocol
+from pynmeagps import NMEAMessage
+from pyrtcm import RTCMMessage
+from pyspartn import SPARTNMessage, date2timetag
+from pyubx2 import NMEA_PROTOCOL, POLL, RTCM3_PROTOCOL, UBX_PROTOCOL, UBXMessage
 from serial import SerialException, SerialTimeoutException
 
 from pygpsclient._version import __version__ as VERSION
@@ -45,19 +58,20 @@ from pygpsclient.globals import (
     CLASS,
     CONFIGFILE,
     CONNECTED,
+    CONNECTED_NTRIP,
+    CONNECTED_SPARTNIP,
+    CONNECTED_SPARTNLB,
     DEFAULT_PASSWORD,
     DEFAULT_REGION,
     DEFAULT_USER,
     DISCONNECTED,
-    DLG,
-    DLGTNTRIP,
     FRAME,
     GNSS_EOF_EVENT,
     GNSS_ERR_EVENT,
     GNSS_EVENT,
     GNSS_TIMEOUT_EVENT,
     GUI_UPDATE_INTERVAL,
-    ICON_APP,
+    ICON_APP128,
     MQTT_PROTOCOL,
     NOPORTS,
     NTRIP_EVENT,
@@ -65,7 +79,8 @@ from pygpsclient.globals import (
     SOCKSERVER_MAX_CLIENTS,
     SPARTN_EVENT,
     SPARTN_OUTPORT,
-    SPARTN_PPSERVER,
+    SPARTN_PPSERVER_URL,
+    SPARTN_PROTOCOL,
     THD,
 )
 from pygpsclient.gnss_status import GNSSStatus
@@ -76,7 +91,9 @@ from pygpsclient.rtcm3_handler import RTCM3Handler
 from pygpsclient.stream_handler import StreamHandler
 from pygpsclient.strings import (
     CONFIGERR,
+    DLG,
     DLGSTOPRTK,
+    DLGTNTRIP,
     ENDOFFILE,
     INACTIVE_TIMEOUT,
     INTROTXTNOPORTS,
@@ -124,6 +141,8 @@ class App(Frame):
         """
 
         self.__master = master
+        self.logger = logging.getLogger(__name__)
+        # self.logger.setLevel(logging.DEBUG)
 
         # user-defined serial port can be passed as environment variable
         # or command line keyword argument
@@ -140,18 +159,22 @@ class App(Frame):
         mqttclientmode = int(
             kwargs.pop("mqttclientmode", getenv("MQTTCLIENTMODE", "0"))
         )
+        spartnkey = kwargs.pop("spartnkey", getenv("MQTTKEY", ""))
         ntripcaster_user = kwargs.pop(
             "ntripcasteruser", getenv("NTRIPCASTER_USER", DEFAULT_USER)
         )
         ntripcaster_password = kwargs.pop(
             "ntripcasterpassword", getenv("NTRIPCASTER_PASSWORD", DEFAULT_PASSWORD)
         )
+        self.ubxsimulator = (
+            kwargs.pop("ubxsimulator", getenv("UBXSIMULATOR", "0")) == "1"
+        )
 
         Frame.__init__(self, self.__master, *args, **kwargs)
 
         self.__master.protocol("WM_DELETE_WINDOW", self.on_exit)
         self.__master.title(TITLE)
-        self.__master.iconphoto(True, PhotoImage(file=ICON_APP))
+        self.__master.iconphoto(True, PhotoImage(file=ICON_APP128))
         self.gnss_status = GNSSStatus()  # holds latest GNSS readings
         self._last_gui_update = datetime.now()
         self._nowidgets = True
@@ -170,8 +193,8 @@ class App(Frame):
         self.nmea_handler = NMEAHandler(self)
         self.ubx_handler = UBXHandler(self)
         self.rtcm_handler = RTCM3Handler(self)
-        self.ntrip_handler = GNSSNTRIPClient(self, verbosity=0)
-        self.spartn_handler = GNSSMQTTClient(self, verbosity=0)
+        self.ntrip_handler = GNSSNTRIPClient(self)
+        self.spartn_handler = GNSSMQTTClient(self)
         self._conn_status = DISCONNECTED
         self._rtk_conn_status = DISCONNECTED
         self._socket_thread = None
@@ -198,6 +221,8 @@ class App(Frame):
             self.saved_config["mqapikey_s"] = mqapikey
         if mqttclientid != "":
             self.saved_config["mqttclientid_s"] = mqttclientid
+        if spartnkey != "":
+            self.saved_config["spartnkey_s"] = spartnkey
         if mqttclientregion != DEFAULT_REGION:
             self.saved_config["mqttclientregion_s"] = mqttclientregion
         if mqttclientmode != 0:
@@ -329,20 +354,23 @@ class App(Frame):
         # force widget to rescale
         frm.event_generate("<Configure>")
 
-        # enable or disable any UBX messages required by widget
-        if hasattr(frm, "enable_messages"):
-            frm.enable_messages(wdg[VISIBLE])
-
         return col, row
 
     def toggle_widget(self, widget: str):
         """
-        Toggle widget visibility.
+        Toggle widget visibility and enable or disable any
+        UBX messages required by widget.
 
         :param str widget: widget name
         """
 
-        widget_state[widget][VISIBLE] = not widget_state[widget][VISIBLE]
+        wdg = widget_state[widget]
+        wdg[VISIBLE] = not wdg[VISIBLE]
+
+        frm = getattr(self, wdg[FRAME])
+        if hasattr(frm, "enable_messages"):
+            frm.enable_messages(wdg[VISIBLE])
+
         self._do_layout()
 
     def reset_widgets(self):
@@ -500,6 +528,7 @@ class App(Frame):
             ntripsettings = {}
             ntripsettings["server"] = self.saved_config.get("ntripclientserver_s", "")
             ntripsettings["port"] = self.saved_config.get("ntripclientport_n", 2101)
+            ntripsettings["https"] = self.saved_config.get("ntripclienthttps_b", 0)
             ntripsettings["ipprot"] = (
                 AF_INET6
                 if self.saved_config.get("ntripclientprotocol_s") == "IPv6"
@@ -516,6 +545,9 @@ class App(Frame):
             ntripsettings["version"] = self.saved_config.get(
                 "ntripclientversion_s", "2.0"
             )
+            ntripsettings["datatype"] = self.saved_config.get(
+                "ntripclientdatatype_s", "RTCM"
+            )
             ntripsettings["ntripuser"] = self.saved_config.get(
                 "ntripclientuser_s", DEFAULT_USER
             )
@@ -532,6 +564,16 @@ class App(Frame):
             ntripsettings["reflon"] = self.saved_config.get("ntripclientreflon_f", 0.0)
             ntripsettings["refalt"] = self.saved_config.get("ntripclientrefalt_f", 0.0)
             ntripsettings["refsep"] = self.saved_config.get("ntripclientrefsep_f", 0.0)
+            ntripsettings["spartndecode"] = self.saved_config.get("spartndecode_b", 0)
+            ntripsettings["spartnkey"] = self.saved_config.get(
+                "spartnkey_s", getenv("MQTTKEY", "")
+            )
+            if ntripsettings["spartnkey"] == "":
+                ntripsettings["spartndecode"] = 0
+            # if basedate is provided in config file, it must be an integer gnssTimetag
+            ntripsettings["spartnbasedate"] = self.saved_config.get(
+                "spartnbasedate_i", date2timetag(datetime.now(timezone.utc))
+            )
             self.ntrip_handler.settings = ntripsettings
 
         except (KeyError, ValueError, TypeError, TclError) as err:
@@ -545,7 +587,7 @@ class App(Frame):
         try:
             spartnsettings = {}
             spartnsettings["server"] = self.saved_config.get(
-                "mqttclientserver_s", SPARTN_PPSERVER
+                "mqttclientserver_s", SPARTN_PPSERVER_URL
             )
             spartnsettings["port"] = self.saved_config.get(
                 "mqttclientport_n", SPARTN_OUTPORT
@@ -571,6 +613,16 @@ class App(Frame):
                 path.join(Path.home(), "device-mqttclientid-pp-key.pem"),
             )
             spartnsettings["output"] = self.spartn_inqueue
+            spartnsettings["spartndecode"] = self.saved_config.get("spartndecode_b", 0)
+            spartnsettings["spartnkey"] = self.saved_config.get(
+                "spartnkey_s", getenv("MQTTKEY", "")
+            )
+            if spartnsettings["spartnkey"] == "":
+                spartnsettings["spartndecode"] = 0
+            # if basedate is provided in config file, it must be an integer gnssTimetag
+            spartnsettings["spartnbasedate"] = self.saved_config.get(
+                "spartnbasedate_i", date2timetag(datetime.now(timezone.utc))
+            )
             self.spartn_handler.settings = spartnsettings
 
         except (KeyError, ValueError, TypeError, TclError) as err:
@@ -777,14 +829,17 @@ class App(Frame):
                 and parsed_data is not None
                 and isinstance(raw_data, bytes)
             ):
-                if protocol(raw_data) == RTCM3_PROTOCOL:
+                if self._rtk_conn_status == CONNECTED_NTRIP:
+                    source = "NTRIP"
+                else:
+                    source = "OTHER"
+                if isinstance(parsed_data, (RTCMMessage, SPARTNMessage)):
                     if self.conn_status == CONNECTED:
                         self.gnss_outqueue.put(raw_data)
-                    self.process_data(raw_data, parsed_data, "NTRIP>>")
-                elif (
-                    protocol(raw_data) == NMEA_PROTOCOL
-                ):  # e.g. NMEA GGA sentence sent to NTRIP server
-                    self.process_data(raw_data, parsed_data, "NTRIP<<")
+                    self.process_data(raw_data, parsed_data, source + ">>")
+                elif isinstance(parsed_data, NMEAMessage):
+                    # i.e. NMEA GGA sentence sent to NTRIP server
+                    self.process_data(raw_data, parsed_data, source + "<<")
             self.ntrip_inqueue.task_done()
         except Empty:
             pass
@@ -804,7 +859,17 @@ class App(Frame):
             if raw_data is not None and parsed_data is not None:
                 if self.conn_status == CONNECTED:
                     self.gnss_outqueue.put(raw_data)
-                self.process_data(raw_data, parsed_data, "SPARTN>>")
+                if self._rtk_conn_status == CONNECTED_SPARTNLB:
+                    source = "LBAND"
+                elif self._rtk_conn_status == CONNECTED_SPARTNIP:
+                    source = "MQTT"
+                else:
+                    source = "OTHER"
+                self.process_data(
+                    raw_data,
+                    parsed_data,
+                    source + ">>",
+                )
             self.spartn_inqueue.task_done()
 
         except Empty:
@@ -833,21 +898,26 @@ class App(Frame):
         if self.dialog(DLGTNTRIP) is not None:
             self.dialog(DLGTNTRIP).set_controls(status, msgt)
 
-    def get_coordinates(self) -> tuple:
+    def get_coordinates(self) -> dict:
         """
-        Get current coordinates.
+        Get current coordinates and fix data.
 
-        :return: tuple (conn_status, lat, lon, alt, sep)
-        :rtype: tuple
+        :return: dict of coords and fix data
+        :rtype: dict
         """
 
-        return (
-            self._conn_status,
-            self.gnss_status.lat,
-            self.gnss_status.lon,
-            self.gnss_status.alt,
-            self.gnss_status.sep,
-        )
+        return {
+            "connection": self._conn_status,
+            "lat": self.gnss_status.lat,
+            "lon": self.gnss_status.lon,
+            "alt": self.gnss_status.alt,
+            "sep": self.gnss_status.sep,
+            "sip": self.gnss_status.sip,
+            "fix": self.gnss_status.fix,
+            "hdop": self.gnss_status.hdop,
+            "diffage": self.gnss_status.diff_age,
+            "diffstation": self.gnss_status.diff_station,
+        }
 
     def process_data(self, raw_data: bytes, parsed_data: object, marker: str = ""):
         """
@@ -858,15 +928,22 @@ class App(Frame):
         :param str marker: string prepended to console entries e.g. "NTRIP>>"
         """
 
+        # self.logger.debug(f"data received {parsed_data.identity}")
         settings = self.frm_settings.config
-
+        msgprot = 0
         protfilter = settings["protocol_n"]
-        msgprot = protocol(raw_data)
-        if isinstance(parsed_data, MQTTMessage):
+        if isinstance(parsed_data, NMEAMessage):
+            msgprot = NMEA_PROTOCOL
+        elif isinstance(parsed_data, UBXMessage):
+            msgprot = UBX_PROTOCOL
+        elif isinstance(parsed_data, RTCMMessage):
+            msgprot = RTCM3_PROTOCOL
+        elif isinstance(parsed_data, SPARTNMessage):
+            msgprot = SPARTN_PROTOCOL
+        elif isinstance(parsed_data, MQTTMessage):
             msgprot = MQTT_PROTOCOL
         elif isinstance(parsed_data, str):
-            marker = "WARNING  "
-            msgprot = 0
+            marker = "WARNING>>"
 
         if msgprot == UBX_PROTOCOL and msgprot & protfilter:
             self.ubx_handler.process_data(raw_data, parsed_data)
@@ -874,6 +951,8 @@ class App(Frame):
             self.nmea_handler.process_data(raw_data, parsed_data)
         elif msgprot == RTCM3_PROTOCOL and msgprot & protfilter:
             self.rtcm_handler.process_data(raw_data, parsed_data)
+        elif msgprot == SPARTN_PROTOCOL and msgprot & protfilter:
+            pass
         elif msgprot == MQTT_PROTOCOL:
             pass
 
@@ -906,9 +985,20 @@ class App(Frame):
         Check for updated version.
         """
 
-        latest = check_latest("PyGPSClient")
+        latest = check_latest(TITLE)
         if latest not in (VERSION, "N/A"):
-            self.set_status(VERCHECK.format(latest), BADCOL)
+            self.set_status(f"{VERCHECK} {latest}", BADCOL)
+
+    def poll_version(self):
+        """
+        Poll MON-VER for device hardware & firmware version.
+        """
+
+        msg = UBXMessage("MON", "MON-VER", POLL)
+        self.gnss_outqueue.put(msg.serialize())
+        self.set_status(
+            "MON-VER POLL message sent",
+        )
 
     @property
     def widget_config(self) -> dict:
