@@ -7,25 +7,25 @@ maintain the state of the various threaded dialogs.
 Created on 16 Aug 2023
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
 from pygpsclient.about_dialog import AboutDialog
-from pygpsclient.globals import (
-    CFG,
-    CLASS,
+from pygpsclient.globals import CFG, CLASS, THD
+from pygpsclient.gpx_dialog import GPXViewerDialog
+from pygpsclient.importmap_dialog import ImportMapDialog
+from pygpsclient.ntrip_client_dialog import NTRIPConfigDialog
+from pygpsclient.spartn_dialog import SPARTNConfigDialog
+from pygpsclient.strings import (
     DLG,
     DLGTABOUT,
     DLGTGPX,
+    DLGTIMPORTMAP,
     DLGTNTRIP,
     DLGTSPARTN,
     DLGTUBX,
-    THD,
 )
-from pygpsclient.gpx_dialog import GPXViewerDialog
-from pygpsclient.ntrip_client_dialog import NTRIPConfigDialog
-from pygpsclient.spartn_dialog import SPARTNConfigDialog
 from pygpsclient.ubx_config_dialog import UBXConfigDialog
 
 dialog_state = {
@@ -34,5 +34,6 @@ dialog_state = {
     DLGTNTRIP: {CLASS: NTRIPConfigDialog, THD: None, DLG: None, CFG: True},
     DLGTSPARTN: {CLASS: SPARTNConfigDialog, THD: None, DLG: None, CFG: True},
     DLGTGPX: {CLASS: GPXViewerDialog, THD: None, DLG: None, CFG: True},
+    DLGTIMPORTMAP: {CLASS: ImportMapDialog, THD: None, DLG: None, CFG: True},
     # add any new dialogs here
 }
