@@ -13,11 +13,12 @@ This handles all the file i/o, including:
 Created on 16 Sep 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
 import json
+import logging
 from datetime import datetime, timedelta
 from pathlib import Path
 from tkinter import filedialog
@@ -25,14 +26,13 @@ from tkinter import filedialog
 from pyubx2 import hextable
 
 from pygpsclient.globals import (
+    APPNAME,
     CONFIGFILE,
-    CONFIGNAME,
     FORMAT_BINARY,
     FORMAT_BOTH,
     FORMAT_HEXSTR,
     FORMAT_HEXTAB,
     FORMAT_PARSED,
-    GITHUB_URL,
     GPX_NS,
     GPX_TRACK_INTERVAL,
     HOME,
@@ -40,7 +40,7 @@ from pygpsclient.globals import (
     XML_HDR,
 )
 from pygpsclient.helpers import set_filename
-from pygpsclient.strings import CONFIGTITLE, READTITLE, SAVETITLE
+from pygpsclient.strings import CONFIGTITLE, GITHUB_URL, READTITLE, SAVETITLE
 
 
 class FileHandler:
@@ -57,6 +57,7 @@ class FileHandler:
 
         self.__app = app  # Reference to main application class
         self.__master = self.__app.appmaster  # Reference to root class (Tk)
+        self.logger = logging.getLogger(__name__)
         self._in_filepath = None
         self._in_filename = None
         self._logpath = None
@@ -164,7 +165,7 @@ class FileHandler:
                 filename = filedialog.asksaveasfilename(
                     title=CONFIGTITLE,
                     initialdir=HOME,
-                    initialfile=f"{CONFIGNAME}.json",
+                    initialfile=f"{APPNAME}.json",
                     filetypes=(
                         ("config files", "*.json"),
                         ("all files", "*.*"),
@@ -200,6 +201,8 @@ class FileHandler:
         Open logfile.
         """
 
+        # pylint: disable=consider-using-with
+
         self._lines = 0
         _, self._logname = set_filename(self._logpath, "data", "log")
         self._logfile = open(self._logname, "a+b")
@@ -332,6 +335,8 @@ class FileHandler:
         Open track file and create GPX track header tags.
         """
 
+        # pylint: disable=consider-using-with
+
         _, self._trackname = set_filename(self._trackpath, "track", "gpx")
         self._trackfile = open(self._trackname, "a", encoding="utf-8")
 
