@@ -8,23 +8,21 @@ Collection of global constants
 Created on 14 Sep 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 
 """
 
 # pylint: disable=line-too-long
 
-from collections import namedtuple
 from datetime import datetime
 from os import path
 from pathlib import Path
 
-from pyubx2 import GET, POLL, SET
+from pyubx2 import GET, POLL, SET, SETPOLL
 
-Point = namedtuple("Point", ["lat", "lon"])
 HOME = Path.home()
-
+APPNAME = __name__.split(".", 1)[0]  # i.e. "pygpsclient"
 BADCOL = "red"
 BGCOL = "gray24"  # default widget background color
 BPSRATES = (
@@ -43,11 +41,11 @@ CFG = "cfg"
 CHECK_FOR_UPDATES = False
 CLASS = "cls"
 COLORTAGS = "colortags"
-CONFIGNAME = "pygpsclient"
-CONFIGFILE = path.join(HOME, f"{CONFIGNAME}.json")
+CONFIGFILE = path.join(HOME, f"{APPNAME}.json")
 CONNECTED = 1
 CONNECTED_FILE = 4
 CONNECTED_NTRIP = 8
+CONNECTED_SIMULATOR = 32
 CONNECTED_SOCKET = 2
 CONNECTED_SPARTNIP = 16
 CONNECTED_SPARTNLB = CONNECTED
@@ -63,22 +61,16 @@ DDD = "DD.D"
 DEFAULT_BUFSIZE = 4096
 DEFAULT_PASSWORD = "password"  # nosec
 DEFAULT_PORT = 50010
+DEFAULT_TLS_PORTS = (443, 2102)
 DEFAULT_REGION = "eu"
 DEFAULT_SERVER = "localhost"
 DEFAULT_USER = "anon"
 DIRNAME = path.dirname(__file__)
 DISCONNECTED = 0
-DLG = "dlg"
-DLGTABOUT = "About"
-DLGTGPX = "GPX Track Viewer"
-DLGTNTRIP = "NTRIP Configuration"
-DLGTSPARTN = "SPARTN Configuration"
-DLGTUBX = "UBX Configuration"
 DMM = "DM.M"
 DMS = "D.M.S"
 ECEF = "ECEF"
 ENABLE_CFG_OTHER = True  # enable CFG=* Other Configuration command panel
-EPILOG = "© 2022 SEMU Consulting BSD 3-Clause license - https://github.com/semuconsulting/pygpsclient/"
 ERRCOL = "pink"  # default invalid data entry field background color
 ERROR = "ERR!"
 FGCOL = "white"  # default widget foreground color
@@ -117,18 +109,16 @@ GNSS_LIST = {
     7: ("NAV", "grey60"),
 }
 GPSEPOCH0 = datetime(1980, 1, 6)  # for Wno and Tow calculations
-GPX_NS = " ".join(
-    (
-        'xmlns="http://www.topografix.com/GPX/1/1"',
-        'creator="PyGPSClient" version="1.1"',
-        'xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"',
-        'xsi:schemaLocation="http://www.topografix.com/GPX/1/1',
-        'http://www.topografix.com/GPX/1/1/gpx.xsd"',
-    )
+GPX_NS = (
+    'xmlns="http://www.topografix.com/GPX/1/1" '
+    'creator="PyGPSClient" version="1.1" '
+    'xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" '
+    'xsi:schemaLocation="http://www.topografix.com/GPX/1/1 '
+    'http://www.topografix.com/GPX/1/1/gpx.xsd"'
 )
 GPX_TRACK_INTERVAL = 1  # minimum GPS track update interval (seconds)
 GUI_UPDATE_INTERVAL = 0.5  # minimum GUI widget update interval (seconds)
-ICON_APP = path.join(DIRNAME, "resources/iconmonstr-location-27-32.png")
+ICON_APP128 = path.join(DIRNAME, "resources/app-128.png")
 ICON_BLANK = path.join(DIRNAME, "resources/blank-1-24.png")
 ICON_CONFIRMED = path.join(DIRNAME, "resources/iconmonstr-check-mark-8-24.png")
 ICON_CONN = path.join(DIRNAME, "resources/iconmonstr-media-control-48-24.png")
@@ -137,6 +127,7 @@ ICON_DELETE = path.join(DIRNAME, "resources/iconmonstr-trash-can-filled-24.png")
 ICON_DISCONN = path.join(DIRNAME, "resources/iconmonstr-media-control-50-24.png")
 ICON_EXIT = path.join(DIRNAME, "resources/iconmonstr-door-6-24.png")
 ICON_EXPAND = path.join(DIRNAME, "resources/iconmonstr-arrow-80-16.png")
+ICON_GITHUB = path.join(DIRNAME, "resources/github-256.png")
 ICON_LOAD = path.join(DIRNAME, "resources/iconmonstr-folder-18-24.png")
 ICON_LOGREAD = path.join(DIRNAME, "resources/binary-1-24.png")
 ICON_NOCLIENT = path.join(DIRNAME, "resources/iconmonstr-noclient-10-24.png")
@@ -144,7 +135,7 @@ ICON_NOTRANSMIT = path.join(DIRNAME, "resources/iconmonstr-notransmit-10-24.png"
 ICON_NTRIPCONFIG = path.join(DIRNAME, "resources/iconmonstr-antenna-4-24.png")
 ICON_PENDING = path.join(DIRNAME, "resources/iconmonstr-time-6-24.png")
 ICON_PLAY = path.join(DIRNAME, "resources/iconmonstr-media-control-48-24.png")
-ICON_POS = path.join(DIRNAME, "resources/iconmonstr-location-1-24.png")
+ICON_POS = path.join(DIRNAME, "resources/iconmonstr-plus-lined-24.png")
 ICON_RECORD = path.join(DIRNAME, "resources/iconmonstr-record-24.png")
 ICON_REDRAW = path.join(DIRNAME, "resources/iconmonstr-refresh-lined-24.png")
 ICON_REFRESH = path.join(DIRNAME, "resources/iconmonstr-refresh-6-16.png")
@@ -160,6 +151,8 @@ ICON_UNDO = path.join(DIRNAME, "resources/iconmonstr-undo-24.png")
 ICON_UNKNOWN = path.join(DIRNAME, "resources/clear-1-24.png")
 ICON_WARNING = path.join(DIRNAME, "resources/iconmonstr-warning-1-24.png")
 IMG_WORLD = path.join(DIRNAME, "resources/world.png")
+ICON_SPONSOR = path.join(DIRNAME, "resources/bmc-full-logo-no-background.png")
+IMG_WORLD_CALIB = [90, -180, -90, 180]
 KM2M = 1000
 KM2MIL = 0.621371
 KM2NMIL = 0.5399568
@@ -183,6 +176,7 @@ KNOWNGPS = (
     "u-blox",
     "U-Blox",
     "ublox",
+    "USB Serial",
     "USB to UART",
     "USB UART",
     "USB_to_UART",
@@ -191,15 +185,18 @@ KNOWNGPS = (
 KPH2KNT = 0.5399568
 KPH2MPH = 0.621371
 KPH2MPS = 0.2777776918389111005
+LICENSE_URL = "https://github.com/semuconsulting/PyGPSClient/blob/master/LICENSE"
 M2FT = 3.28084
+MAPAPI_URL = "https://developer.mapquest.com/user/login/sign-up"
 MAX_SNR = 60  # upper limit of graphview snr axis
 MAXLOGLINES = 10000  # maximum number of 'lines' per datalog file
 MQAPIKEY = "mqapikey"
-MQTT_PROTOCOL = 6
+MQTT_PROTOCOL = 16
 MSGMODES = {
     "GET": GET,
     "SET": SET,
     "POLL": POLL,
+    "SETPOLL": SETPOLL,
 }
 NOPORTS = 3
 NTRIP_EVENT = "<<ntrip_read>>"
@@ -209,7 +206,8 @@ PORTIDS = ("0 I2C", "1 UART1", "2 UART2", "3 USB", "4 SPI")
 PUBLICIP_URL = "https://ipinfo.io/json"
 PYPI_URL = "https://pypi.org/pypi/PyGPSClient"
 QUITONERRORDEFAULT = 1
-RCVR_CONNECTION = "USB"  # default GNSS receiver connection port
+RCVR_CONNECTION = "USB,UART1"  # default GNSS receiver connection port(s)
+ROMVER_NEW = "23.01"  # min device ROM version using configuration database
 READONLY = "readonly"
 RXMMSG = "RXM-SPARTN-KEY"
 SAT_EXPIRY = 10  # how long passed satellites are kept in the sky and graph view
@@ -229,10 +227,11 @@ SPARTN_EVENT = "<<spartn_read>>"
 SPARTN_KEYLEN = 16
 SPARTN_OUTPORT = 8883
 SPARTN_PPREGIONS = ("eu", "us", "jp", "kr", "au")
-SPARTN_PPSERVER = "pp.services.u-blox.com"
-SPARTN_PPSERVER = "pp.services.u-blox.com"
+SPARTN_PPSERVER_URL = "pp.services.u-blox.com"
+SPARTN_PROTOCOL = 8
 SPARTN_SOURCE_IP = 0
 SPARTN_SOURCE_LB = 1
+SPONSOR_URL = "https://buymeacoffee.com/semuconsulting"
 THD = "thd"
 TIMEOUTS = (
     "0.1",
@@ -249,10 +248,12 @@ TOPIC_IP = "/pp/ip/{}"
 TOPIC_MGA = "/pp/ubx/mga"
 TOPIC_RXM = "/pp/ubx/0236/ip"
 UBXPRESETS = "ubxpresets"
+UBXSIMULATOR = "ubxsimulator"
 UI = "Imperial mph"
 UIK = "Imperial knots"
 UMK = "Metric kmph"
 UMM = "Metric m/s"
+UTF8 = "utf-8"
 WIDGETU1 = (250, 250)  # small widget size
 WIDGETU2 = (350, 250)  # medium widget size
 WIDGETU3 = (950, 350)  # Console size
@@ -276,6 +277,7 @@ SPARTN_MQTT = 10
 SPECTRUMVIEW = 11
 SYSMONVIEW = 12
 ROVERVIEW = 13
+UBX_MONRF = 14
 
 # map of fix values to descriptions
 # the keys in this map are a concatenation of NMEA/UBX
