@@ -8,11 +8,11 @@ Container for the latest readings from the GNSS receiver.
 Created on 07 Apr 2022
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2022
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
-from datetime import datetime
+from datetime import datetime, timezone
 
 
 class GNSSStatus:
@@ -26,7 +26,7 @@ class GNSSStatus:
         Constructor.
         """
 
-        self.utc = datetime.utcnow().time().replace(microsecond=0)  # UTC time
+        self.utc = datetime.now(timezone.utc).time().replace(microsecond=0)  # UTC time
         self.lat = 0.0  # latitude as decimal
         self.lon = 0.0  # longitude as decimal
         self.alt = 0.0  # height above sea level m
@@ -50,6 +50,7 @@ class GNSSStatus:
         self.acc_length = 0.0  # rover relative position distance accuracy
         self.rel_pos_flags = []  # rover relative position flags
         self.gsv_data = []  # list of satellite tuples (gnssId, svid, elev, azim, cno)
-        self.spectrum_data = []  # list of spectrum data (spec, spn, res, ctr, pga)
+        self.version_data = {}  # dict of hardware, firmware and software versions
         self.sysmon_data = {}  # dict of system monitor data (cpu and memory load, etc.)
+        self.spectrum_data = []  # list of spectrum data (spec, spn, res, ctr, pga)
         self.comms_data = {}  # dict of comms port utilisation (tx and rx loads)
