@@ -8,7 +8,7 @@ Collection of helper methods.
 Created on 17 Apr 2021
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2021
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 
 """
@@ -22,7 +22,7 @@ from time import strftime
 from tkinter import Button, Entry, Label, Toplevel, W, font
 
 from pynmeagps import haversine
-from pyubx2 import SET, UBX_MSGIDS, UBXMessage, attsiz, atttyp
+from pyubx2 import SET, SET_LAYER_RAM, TXN_NONE, UBX_MSGIDS, UBXMessage, attsiz, atttyp
 from requests import get
 
 from pygpsclient.globals import (
@@ -31,6 +31,7 @@ from pygpsclient.globals import (
     MAX_SNR,
     PUBLICIP_URL,
     RCVR_CONNECTION,
+    ROMVER_NEW,
 )
 from pygpsclient.strings import NA
 
@@ -337,6 +338,7 @@ def hsv2rgb(h: float, s: float, v: float) -> str:
     :rtype: str
     """
 
+    r = g = b = 0
     v = int(v * 255)
     if s == 0.0:
         return rgb2str(v, v, v)
@@ -431,26 +433,25 @@ def get_mp_info(srt: list) -> dict:
     """
 
     try:
-        info = {
+        return {
             "name": srt[0],
             "identifier": srt[1],
             "format": srt[2],
             "messages": srt[3],
-            "carrier": CARRIERS[srt[4]],
+            "carrier": CARRIERS.get(srt[4], srt[4]),
             "navs": srt[5],
             "network": srt[6],
             "country": srt[7],
             "lat": srt[8],
             "lon": srt[9],
-            "gga": NMEA[srt[10]],
-            "solution": SOLUTIONS[srt[11]],
+            "gga": NMEA.get(srt[10], srt[10]),
+            "solution": SOLUTIONS.get(srt[11], srt[11]),
             "generator": srt[12],
             "encrypt": srt[13],
-            "auth": AUTHS[srt[14]],
+            "auth": AUTHS.get(srt[14], srt[14]),
             "fee": srt[15],
             "bitrate": srt[16],
         }
-        return info
     except IndexError:
         return None
 
@@ -800,12 +801,14 @@ def sizefont(height: int, lines: int, minfont: int) -> tuple:
     return fnt, fh
 
 
-def setubxrate(app: object, mid: str, rate: int = 1) -> UBXMessage:
+def setubxrate(app: object, mid: str, rate: int = 1, prot: str = "UBX") -> UBXMessage:
     """
     Set rate on specified UBX message on default port(s).
 
+    Uses either CFG-MSG or CFG-VALSET command, depending on device ROM version.
+
     The port(s) this applies to are defined in the 'defaultport_s'
-    configuration setting as a comma-separated string.
+    configuration setting as a comma-separated string e.g. "USB,UART1".
 
     Rate is relative to navigation solution e.g.
     a rate of '4' means 'every 4th navigation solution'
@@ -814,40 +817,61 @@ def setubxrate(app: object, mid: str, rate: int = 1) -> UBXMessage:
     :param object application: reference to calling application
     :param str mid: message identity e.g. "MON-SPAN"
     :param int rate: message rate (0 = off)
-    :return: UBX command generated
+    :param str prot: message protocol ("UBX", "NMEA_ID", "PUBX_ID", "RTCM_3X_TYPE")
+    :return: UBX set rate command
     :rtype: UBXMessage
     :raises: ValueError if unknown message identity
     """
 
     rates = {}
-    prts = app.frm_settings.config.get(
-        "defaultport_s", app.frm_settings.config.get("defaultport", RCVR_CONNECTION)
-    ).split(",")
-    for prt in prts:
-        rates[prt] = rate
-
-    msgclass = msgid = None
-    for msgtype, msgnam in UBX_MSGIDS.items():
-        if msgnam == mid:
-            msgclass = msgtype[0]
-            msgid = msgtype[1]
-            break
-    if msgclass is None or msgid is None:
-        raise ValueError(f"Message ID {mid} unknown")
-
-    msg = UBXMessage(
-        "CFG",
-        "CFG-MSG",
-        SET,
-        msgClass=msgclass,
-        msgID=msgid,
-        rateDDC=rates.get("I2C", 0),
-        rateUART1=rates.get("UART1", 0),
-        rateUART2=rates.get("UART2", 0),
-        rateUSB=rates.get("USB", 0),
-        rateSPI=rates.get("SPI", 0),
+    msg = None
+    # select which receiver ports to apply rate to
+    prts = (
+        app.frm_settings.config.get("defaultport_s", RCVR_CONNECTION).upper().split(",")
     )
-    app.gnss_outqueue.put(msg.serialize())
+
+    # check device ROM version for configuration support
+    romver = app.gnss_status.version_data.get("romversion", NA).replace(NA, "")
+    if romver >= ROMVER_NEW:
+
+        # new style message rate configuration using CFG-VALSET & configuration database keys:
+        prot = prot + "_" if prot != "RTCM_3X_TYPE" else prot
+        mid = mid.replace("-", "_")
+        for prt in prts:
+            if prt != "":
+                cfgdata = [(f"CFG_MSGOUT_{prot}{mid}_{prt}", rate)]
+                msg = UBXMessage.config_set(SET_LAYER_RAM, TXN_NONE, cfgdata)
+                app.gnss_outqueue.put(msg.serialize())
+
+    else:
+
+        # old style message rate configuration usng CFG-MSG:
+        for prt in prts:
+            rates[prt] = rate
+
+        msgclass = msgid = None
+        for msgtype, msgnam in UBX_MSGIDS.items():
+            if msgnam == mid:
+                msgclass = msgtype[0]
+                msgid = msgtype[1]
+                break
+        if msgclass is None or msgid is None:
+            raise ValueError(f"Message ID {mid} unknown")
+
+        msg = UBXMessage(
+            "CFG",
+            "CFG-MSG",
+            SET,
+            msgClass=msgclass,
+            msgID=msgid,
+            rateDDC=rates.get("I2C", 0),
+            rateUART1=rates.get("UART1", 0),
+            rateUART2=rates.get("UART2", 0),
+            rateUSB=rates.get("USB", 0),
+            rateSPI=rates.get("SPI", 0),
+        )
+        app.gnss_outqueue.put(msg.serialize())
+
     return msg
 
 
@@ -906,7 +930,7 @@ def adjust_dimensions(dim: int) -> int:
     if system() == "Windows":
         return int(dim * 0.95)
     if system() == "Darwin":
-        return int(dim * 0.9)
+        return int(dim * 0.93)
     return int(dim)
 
 
