@@ -14,10 +14,11 @@ the threaded NTRIP handler itself, NOT in this frame.
 Created on 2 Apr 2022
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2022
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
+from logging import getLogger
 from socket import AF_INET, AF_INET6
 from tkinter import (
     DISABLED,
@@ -51,7 +52,6 @@ from pygnssutils.helpers import find_mp_distance
 from pygpsclient.globals import (
     CONNECTED_NTRIP,
     DISCONNECTED,
-    DLGTNTRIP,
     GGA_INTERVALS,
     ICON_CONN,
     ICON_DISCONN,
@@ -73,6 +73,7 @@ from pygpsclient.helpers import MAXALT, VALFLOAT, get_mp_info, valid_entry
 from pygpsclient.socketconfig_frame import SocketConfigFrame
 from pygpsclient.strings import (
     DLGNTRIPCONFIG,
+    DLGTNTRIP,
     LBLGGAFIXED,
     LBLGGALIVE,
     LBLNTRIPGGAINT,
@@ -87,6 +88,9 @@ NTRIP_VERSIONS = ("2.0", "1.0")
 KM2MILES = 0.6213712
 IP4 = "IPv4"
 IP6 = "IPv6"
+RTCM = "RTCM"
+SPARTN = "SPARTN"
+NTRIP_SPARTN = "ppntrip.services.u-blox.com"
 
 
 class NTRIPConfigDialog(Toplevel):
@@ -104,6 +108,7 @@ class NTRIPConfigDialog(Toplevel):
         """
 
         self.__app = app  # Reference to main application class
+        self.logger = getLogger(__name__)
         self.__master = self.__app.appmaster  # Reference to root class (Tk)
         self._saved_config = kwargs.pop(SAVED_CONFIG, {})
 
@@ -127,6 +132,8 @@ class NTRIPConfigDialog(Toplevel):
             UBX_CFGRATE: (),
         }
         self._status = StringVar()
+        self._ntrip_datatype = StringVar()
+        self._ntrip_https = IntVar()
         self._ntrip_version = StringVar()
         self._ntrip_mountpoint = StringVar()
         self._ntrip_mpdist = StringVar()
@@ -163,12 +170,14 @@ class NTRIPConfigDialog(Toplevel):
             ),
             "sockclientflowinfo_n": self._saved_config.get("ntripclientflowinfo_n", 0),
             "sockclientscopeid_n": self._saved_config.get("ntripclientscopeid_n", 0),
+            "sockclienthttps_b": self._saved_config.get("ntripclienthttps_b", 0),
             "protocols_l": [IP4, IP6],
         }
         self._frm_socket = SocketConfigFrame(
             self.__app,
             self._frm_container,
             saved_config=saved_ntrip_config,
+            server_callback=self._on_server,
         )
         self._frm_status = Frame(self._frm_container, borderwidth=2, relief="groove")
         self._lbl_status = Label(
@@ -190,6 +199,7 @@ class NTRIPConfigDialog(Toplevel):
             relief="sunken",
             width=15,
         )
+
         self._lbl_mpdist = Label(
             self._frm_container,
             textvariable=self._ntrip_mpdist,
@@ -219,6 +229,15 @@ class NTRIPConfigDialog(Toplevel):
             textvariable=self._ntrip_version,
             state=READONLY,
         )
+        self._lbl_datatype = Label(self._frm_container, text="Data Type")
+        self._spn_datatype = Spinbox(
+            self._frm_container,
+            values=(RTCM, SPARTN),
+            width=8,
+            wrap=True,
+            textvariable=self._ntrip_datatype,
+            state=READONLY,
+        )
         self._lbl_user = Label(self._frm_container, text=LBLNTRIPUSER)
         self._ent_user = Entry(
             self._frm_container,
@@ -340,9 +359,9 @@ class NTRIPConfigDialog(Toplevel):
         self._scr_sourcetablev.grid(column=4, row=5, rowspan=4, sticky=(N, S))
         self._scr_sourcetableh.grid(column=1, columnspan=3, row=9, sticky=(E, W))
         self._lbl_ntripversion.grid(column=0, row=10, padx=3, pady=3, sticky=W)
-        self._spn_ntripversion.grid(
-            column=1, row=10, padx=3, pady=3, rowspan=2, sticky=W
-        )
+        self._spn_ntripversion.grid(column=1, row=10, padx=3, pady=3, sticky=W)
+        self._lbl_datatype.grid(column=0, row=11, padx=3, pady=3, sticky=W)
+        self._spn_datatype.grid(column=1, row=11, padx=3, pady=3, sticky=W)
         self._lbl_user.grid(column=0, row=12, padx=3, pady=3, sticky=W)
         self._ent_user.grid(column=1, row=12, columnspan=3, padx=3, pady=3, sticky=W)
         self._lbl_password.grid(column=0, row=13, padx=3, pady=3, sticky=W)
@@ -445,6 +464,7 @@ class NTRIPConfigDialog(Toplevel):
             for ctl in (
                 self._spn_ntripversion,
                 self._spn_ntripggaint,
+                self._spn_datatype,
             ):
                 ctl.config(state=(DISABLED if connected else READONLY))
 
@@ -503,6 +523,7 @@ class NTRIPConfigDialog(Toplevel):
             srt = w.get(index)  # sourcetable entry
             name = srt[0]
             info = get_mp_info(srt)
+            # self.logger.debug(f"MP info: {name} {info}")
             notes = (
                 ""
                 if info is None
@@ -521,6 +542,21 @@ class NTRIPConfigDialog(Toplevel):
         except (IndexError, KeyError):  # not yet populated
             pass
 
+    def _on_server(self, var, index, mode):  # pylint: disable=unused-argument
+        """
+        Callback when server URL changed.
+
+        :param event event: write event
+        """
+
+        try:
+            if self._frm_socket.server.get() == NTRIP_SPARTN:
+                self._ntrip_datatype.set(SPARTN)
+            else:
+                self._ntrip_datatype.set(RTCM)
+        except TclError:
+            pass
+
     def on_exit(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
         Handle Exit button press.
@@ -551,8 +587,10 @@ class NTRIPConfigDialog(Toplevel):
         self._frm_socket.protocol.set(IP6 if ipprot == AF_INET6 else IP4)
         self._frm_socket.server.set(self._settings["server"])
         self._frm_socket.port.set(self._settings["port"])
+        self._frm_socket.https.set(self._settings["https"])
         self._ntrip_mountpoint.set(self._settings["mountpoint"])
         self._ntrip_version.set(self._settings["version"])
+        self._ntrip_datatype.set(self._settings["datatype"])
         self._ntrip_user.set(self._settings["ntripuser"])
         self._ntrip_password.set(self._settings["ntrippassword"])
         ggaint = self._settings["ggainterval"]
@@ -576,11 +614,13 @@ class NTRIPConfigDialog(Toplevel):
 
         self._settings["server"] = self._frm_socket.server.get()
         self._settings["port"] = self._frm_socket.port.get()
+        self._settings["https"] = self._frm_socket.https.get()
         self._settings["ipprot"] = (
             AF_INET6 if self._frm_socket.protocol.get() == IP6 else AF_INET
         )
         self._settings["mountpoint"] = self._ntrip_mountpoint.get()
         self._settings["version"] = self._ntrip_version.get()
+        self._settings["datatype"] = self._ntrip_datatype.get()
         self._settings["ntripuser"] = self._ntrip_user.get()
         self._settings["ntrippassword"] = self._ntrip_password.get()
         ggaint = self._ntrip_gga_interval.get()
@@ -612,14 +652,17 @@ class NTRIPConfigDialog(Toplevel):
 
         if self._valid_settings():
             self._set_settings()
+            # verbosity and logtofile set in App.__init__()
             self.__app.ntrip_handler.run(
                 ipprot=IP6 if self._settings["ipprot"] == AF_INET6 else IP4,
                 server=self._settings["server"],
                 port=self._settings["port"],
+                https=self._settings["https"],
                 flowinfo=self._settings["flowinfo"],
                 scopeid=self._settings["scopeid"],
                 mountpoint=self._settings["mountpoint"],
                 version=self._settings["version"],
+                datatype=self._settings["datatype"],
                 ntripuser=self._settings["ntripuser"],
                 ntrippassword=self._settings["ntrippassword"],
                 ggainterval=self._settings["ggainterval"],
@@ -628,6 +671,9 @@ class NTRIPConfigDialog(Toplevel):
                 reflon=self._settings["reflon"],
                 refalt=self._settings["refalt"],
                 refsep=self._settings["refsep"],
+                spartndecode=self._settings["spartndecode"],
+                spartnkey=self._settings["spartnkey"],
+                spartnbasedate=self._settings["spartnbasedate"],
                 output=self.__app.ntrip_inqueue,
             )
             self.set_controls(True)
@@ -691,8 +737,10 @@ class NTRIPConfigDialog(Toplevel):
         """
 
         try:
-            if self._settings.get("ggamode", 0) == 0:  # live position
-                _, lat, lon, _, _ = self.__app.get_coordinates()
+            # if self._settings.get("ggamode", 0) == 0:  # live position
+            if self._ntrip_gga_mode.get() == 0:  # live position
+                status = self.__app.get_coordinates()
+                lat, lon = status["lat"], status["lon"]
             else:  # fixed reference
                 lat = float(self._settings["reflat"])
                 lon = float(self._settings["reflon"])
