@@ -9,7 +9,7 @@ fixed or moving base RTK configuration.
 Created on 22 Aug 2023
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2022
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
@@ -179,7 +179,7 @@ class RoverFrame(Frame):
         self.canvas.create_text(
             ls,
             ls,
-            text=f"Len {dis:.2f} ± {accdis:.2f} cm",
+            text=f"Len {dis:,.2f} ± {accdis:.2f} cm",
             fill=PNTCOL,
             anchor="nw",
             font=self.lbl_font,
