@@ -14,7 +14,7 @@ Application icons from https://iconmonstr.com/license/.
 Created on 24 Dec 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
@@ -42,7 +42,7 @@ from tkinter import (
 )
 
 from PIL import Image, ImageTk
-from pyubx2 import GET, POLL, SET
+from pyubx2 import GET, POLL, SET, SETPOLL
 from serial import PARITY_EVEN, PARITY_MARK, PARITY_NONE, PARITY_ODD, PARITY_SPACE
 from serial.tools.list_ports import comports
 
@@ -57,12 +57,13 @@ CONNECTED = 1
 CONNECTED_FILE = 2
 DATABITS_RNG = (8, 5, 6, 7)
 DISCONNECTED = 0
-MSGMODES = {
+MSGMODED = {
     GET: "GET",
     SET: "SET",
     POLL: "POLL",
+    SETPOLL: "SETPOLL",
 }
-MSGMODE_RNG = list(MSGMODES.values())
+MSGMODE_RNG = list(MSGMODED.values())
 NOPORTS = 3
 PARITIES = {
     PARITY_NONE: "None",
@@ -140,7 +141,7 @@ class SerialConfigFrame(Frame):
             self._frm_basic,
             border=2,
             relief="sunken",
-            width=32,
+            width=38,
             height=5,
             justify=LEFT,
             exportselection=False,
@@ -222,7 +223,7 @@ class SerialConfigFrame(Frame):
         self._spn_msgmode_name = Spinbox(
             self._frm_advanced,
             values=self._msgmode_name_rng,
-            width=4,
+            width=7,
             state=READONLY,
             wrap=True,
             textvariable=self._msgmode_name,
@@ -254,14 +255,14 @@ class SerialConfigFrame(Frame):
         self._frm_basic.grid(column=0, row=0, columnspan=4, sticky=(W, E))
         self._lbl_port.grid(column=0, row=0, sticky=W)
         self._lbx_port.grid(
-            column=1, row=0, columnspan=2, sticky=(W, E), padx=3, pady=2
+            column=1, row=0, columnspan=3, sticky=(W, E), padx=3, pady=2
         )
-        self._scr_portv.grid(column=3, row=0, sticky=(N, S))
-        self._scr_porth.grid(column=1, row=1, columnspan=2, sticky=(E, W))
+        self._scr_portv.grid(column=4, row=0, sticky=(N, S))
+        self._scr_porth.grid(column=1, row=1, columnspan=3, sticky=(E, W))
         self._lbl_bpsrate.grid(column=0, row=2, sticky=W)
         self._spn_bpsrate.grid(column=1, row=2, sticky=W, padx=3, pady=2)
-        self._btn_refresh.grid(column=2, row=2, sticky=E)
-        self._btn_toggle.grid(column=3, row=2, sticky=E)
+        self._btn_refresh.grid(column=3, row=2, sticky=E)
+        self._btn_toggle.grid(column=4, row=2, sticky=E)
 
         self._frm_advanced.grid_forget()
         self._lbl_databits.grid(column=0, row=0, sticky=W)
@@ -304,7 +305,7 @@ class SerialConfigFrame(Frame):
         self._rtscts.set(self._saved_config.get("rtscts_b", False))
         self._xonxoff.set(self._saved_config.get("xonxoff_b", False))
         self._timeout.set(self._saved_config.get("timeout_f", self._timeout_rng[0]))
-        self._msgmode_name.set(MSGMODES[self._saved_config.get("msgmode_n", GET)])
+        self._msgmode_name.set(MSGMODED[self._saved_config.get("msgmode_n", GET)])
         self._inactivity_timeout.set(self._saved_config.get("inactivity_timeout_n", 0))
         self.user_defined_port.set(self._saved_config.get("userport_s", ""))
         self._on_refresh()
@@ -555,15 +556,17 @@ class SerialConfigFrame(Frame):
         Return message parsing mode
         Default is GET i.e. input from receiver.
 
-        :return: message mode 0 = POLL 1 = SET, 2 = POLL
+        :return: message mode 0 = POLL 1 = SET, 2 = POLL, 3 = SETPOLL
         :rtype: int
         """
 
-        # return MSGMODES[self._msgmode.get()]
-        if self._msgmode_name.get() == MSGMODES[SET]:
+        # return MSGMODED[self._msgmode.get()]
+        if self._msgmode_name.get() == MSGMODED[SET]:
             return SET
-        if self._msgmode_name.get() == MSGMODES[POLL]:
+        if self._msgmode_name.get() == MSGMODED[POLL]:
             return POLL
+        if self._msgmode_name.get() == MSGMODED[SETPOLL]:
+            return SETPOLL
         return GET
 
     @property
