@@ -13,7 +13,7 @@ to be increased if the correction source is intermittent.
 Created on 26 Jan 2023
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2023
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
@@ -345,10 +345,12 @@ class SPARTNGNSSDialog(Frame):
             if self._disable_nmea.get():
                 cfgdata.append((f"CFG_{port}OUTPROT_NMEA", 0))
                 cfgdata.append((f"CFG_MSGOUT_UBX_NAV_PVT_{port}", 1))
+                cfgdata.append((f"CFG_MSGOUT_UBX_NAV_DOP_{port}", 1))
                 cfgdata.append((f"CFG_MSGOUT_UBX_NAV_SAT_{port}", 4))
             else:
                 cfgdata.append((f"CFG_{port}OUTPROT_NMEA", 1))
                 # cfgdata.append((f"CFG_MSGOUT_UBX_NAV_PVT_{port}", 0))
+                # cfgdata.append((f"CFG_MSGOUT_UBX_NAV_DOP_{port}", 0))
                 # cfgdata.append((f"CFG_MSGOUT_UBX_NAV_SAT_{port}", 0))
 
         msg = UBXMessage.config_set(SET_LAYER_RAM, TXN_NONE, cfgdata)
@@ -476,6 +478,8 @@ class SPARTNGNSSDialog(Frame):
                 self._spartn_valdate1.set(keydata[0][1].strftime("%Y%m%d"))
                 self._spartn_key2.set(keydata[1][0])
                 self._spartn_valdate2.set(keydata[1][1].strftime("%Y%m%d"))
+                # save latest key in configuration settings
+                self.__app.saved_config["spartnkey_s"] = self._spartn_key1.get()
                 col = "green"
             else:
                 col = "red"
