@@ -19,7 +19,7 @@ find as 'confirmed'.
 Created on 19 Sep 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
@@ -30,8 +30,8 @@ from pyubx2 import UBXMessage
 
 from pygpsclient.globals import (
     CONNECTED,
+    CONNECTED_SIMULATOR,
     CONNECTED_SOCKET,
-    DLGTUBX,
     ENABLE_CFG_OTHER,
     ICON_EXIT,
     POPUP_TRANSIENT,
@@ -42,10 +42,11 @@ from pygpsclient.globals import (
     UBX_CFGRATE,
     UBX_CFGVAL,
     UBX_MONHW,
+    UBX_MONRF,
     UBX_MONVER,
     UBX_PRESET,
 )
-from pygpsclient.strings import DLGUBXCONFIG
+from pygpsclient.strings import DLGTUBX, DLGUBXCONFIG
 from pygpsclient.ubx_cfgval_frame import UBX_CFGVAL_Frame
 from pygpsclient.ubx_dynamic_frame import UBX_Dynamic_Frame
 from pygpsclient.ubx_info_frame import UBX_INFO_Frame
@@ -237,7 +238,11 @@ class UBXConfigDialog(Toplevel):
         self._frm_config_port.reset()
         self._frm_config_dynamic.reset()
         self._frm_device_info.reset()
-        if self.__app.conn_status not in (CONNECTED, CONNECTED_SOCKET):
+        if self.__app.conn_status not in (
+            CONNECTED,
+            CONNECTED_SOCKET,
+            CONNECTED_SIMULATOR,
+        ):
             self.set_status("Device not connected", "red")
 
     def set_pending(self, msgid: int, ubxfrm: int):
@@ -262,7 +267,7 @@ class UBXConfigDialog(Toplevel):
         ubxfrm = self._pending_confs.get(msg.identity, None)
 
         if ubxfrm is not None:
-            if ubxfrm in (UBX_MONVER, UBX_MONHW):
+            if ubxfrm in (UBX_MONVER, UBX_MONHW, UBX_MONRF):
                 self._frm_device_info.update_status(msg)
             elif ubxfrm == UBX_CFGPRT:
                 self._frm_config_port.update_status(msg)
