@@ -11,14 +11,17 @@ update the various user-selectable widget panels.
 Created on 30 Sep 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
+import logging
+
 from pyubx2 import UBXMessage, itow2utc
 
-from pygpsclient.globals import DLGTSPARTN, DLGTUBX, GLONASS_NMEA
+from pygpsclient.globals import GLONASS_NMEA, UTF8
 from pygpsclient.helpers import corrage2int, fix2desc, ned2vector, svid2gnssid
+from pygpsclient.strings import DLGTSPARTN, DLGTUBX, NA
 from pygpsclient.widget_state import VISIBLE, WDGSPECTRUM, WDGSYSMON
 
 
@@ -36,6 +39,7 @@ class UBXHandler:
 
         self.__app = app  # Reference to main application class
         self.__master = self.__app.appmaster  # Reference to root class (Tk)
+        self.logger = logging.getLogger(__name__)
 
         self._cdb = 0
         self._raw_data = None
@@ -54,10 +58,10 @@ class UBXHandler:
 
         if raw_data is None:
             return
-
+        # self.logger.debug(f"data received {parsed_data.identity}")
         if parsed_data.identity[0:3] in ("ACK", "CFG"):
             self._process_ACK(parsed_data)
-        elif parsed_data.identity in ("MON-VER", "MON-HW"):
+        elif parsed_data.identity == "MON-VER":
             self._process_MONVER(parsed_data)
         elif parsed_data.identity in ("NAV-POSLLH", "NAV-HPPOSLLH"):
             self._process_NAV_POSLLH(parsed_data)
@@ -71,7 +75,7 @@ class UBXHandler:
             self._process_NAV_VELNED(parsed_data)
         elif parsed_data.identity in ("NAV-SAT", "NAV2-SAT"):
             self._process_NAV_SAT(parsed_data)
-        elif parsed_data.identity in ("NAV-STATUS", "NAV2-STATUS)"):
+        elif parsed_data.identity in ("NAV-STATUS", "NAV2-STATUS"):
             self._process_NAV_STATUS(parsed_data)
         elif parsed_data.identity == "NAV-SVIN":
             self._process_NAV_SVIN(parsed_data)
@@ -120,11 +124,57 @@ class UBXHandler:
 
     def _process_MONVER(self, msg: UBXMessage):
         """
-        Process MON-VER & MON-HW sentences.
+        Process MON-VER sentences.
 
-        :param UBXMessage msg: UBX config message
+        :param UBXMessage msg: UBX MON-VER config message
         """
 
+        exts = []
+        fw_version = NA
+        rom_version = NA
+        gnss_supported = ""
+        model = ""
+        sw_version = getattr(msg, "swVersion", b"N/A")
+        sw_version = sw_version.replace(b"\x00", b"").decode(UTF8)
+        sw_version = sw_version.replace("ROM CORE", "ROM")
+        sw_version = sw_version.replace("EXT CORE", "Flash")
+        hw_version = getattr(msg, "hwVersion", b"N/A")
+        hw_version = hw_version.replace(b"\x00", b"").decode(UTF8)
+
+        for i in range(9):
+            ext = getattr(msg, f"extension_{i+1:02d}", b"")
+            ext = ext.replace(b"\x00", b"").decode(UTF8)
+            exts.append(ext)
+            if "FWVER=" in exts[i]:
+                fw_version = exts[i].replace("FWVER=", "")
+            if "PROTVER=" in exts[i]:
+                rom_version = exts[i].replace("PROTVER=", "")
+            if "PROTVER " in exts[i]:
+                rom_version = exts[i].replace("PROTVER ", "")
+            if "MOD=" in exts[i]:
+                model = exts[i].replace("MOD=", "")
+                hw_version = f"{model} {hw_version}"
+            for gnss in (
+                "GPS",
+                "GLO",
+                "GAL",
+                "BDS",
+                "SBAS",
+                "IMES",
+                "QZSS",
+                "NAVIC",
+            ):
+                if gnss in exts[i]:
+                    gnss_supported = gnss_supported + gnss + " "
+
+        verdata = {}
+        verdata["swversion"] = sw_version
+        verdata["hwversion"] = hw_version
+        verdata["fwversion"] = fw_version
+        verdata["romversion"] = rom_version
+        verdata["gnss"] = gnss_supported
+        self.__app.gnss_status.version_data = verdata
+
         if self.__app.dialog(DLGTUBX) is not None:
             self.__app.dialog(DLGTUBX).update_pending(msg)
 
@@ -218,7 +268,10 @@ class UBXHandler:
         if data.carrSoln > 0:
             self.__app.gnss_status.fix = fix2desc("NAV-PVT", data.carrSoln + 5)
 
-        self.__app.gnss_status.diff_corr = data.difSoln
+        if hasattr(data, "difSoln"):  # for pyubx2 <= 1.2.42
+            self.__app.gnss_status.diff_corr = data.difSoln
+        elif hasattr(data, "diffSoln"):
+            self.__app.gnss_status.diff_corr = data.diffSoln
         if data.lastCorrectionAge != 0:
             self.__app.gnss_status.diff_age = corrage2int(data.lastCorrectionAge)
 
