@@ -6,7 +6,7 @@ UBX Configuration frame for preset and user-defined commands
 Created on 22 Dec 2020
 
 :author: semuadmin
-:copyright: SEMU Consulting © 2020
+:copyright: 2020 SEMU Consulting
 :license: BSD 3-Clause
 """
 
@@ -15,8 +15,10 @@ from tkinter import (
     LEFT,
     VERTICAL,
     Button,
+    Checkbutton,
     E,
     Frame,
+    IntVar,
     Label,
     Listbox,
     N,
@@ -54,6 +56,8 @@ from pygpsclient.strings import (
     PSTALLNMEAON,
     PSTALLRXMOFF,
     PSTALLRXMON,
+    PSTALLSECOFF,
+    PSTALLSECON,
     PSTALLUBXOFF,
     PSTALLUBXON,
     PSTMINNMEAON,
@@ -64,11 +68,15 @@ from pygpsclient.strings import (
     PSTPOLLPORT,
     PSTRESET,
     PSTSAVE,
+    PSTUSENMEA,
+    PSTUSEUBX,
 )
 
 PRESET_COMMMANDS = [
     PSTRESET,
     PSTSAVE,
+    PSTUSEUBX,
+    PSTUSENMEA,
     PSTMINNMEAON,
     PSTALLNMEAON,
     PSTALLNMEAOFF,
@@ -83,6 +91,8 @@ PRESET_COMMMANDS = [
     PSTALLMONOFF,
     PSTALLRXMON,
     PSTALLRXMOFF,
+    PSTALLSECON,
+    PSTALLSECOFF,
     PSTPOLLPORT,
     PSTPOLLINFO,
     PSTPOLLALLCFG,
@@ -122,6 +132,12 @@ class UBX_PRESET_Frame(Frame):
         self._img_warn = ImageTk.PhotoImage(Image.open(ICON_WARNING))
         self._preset_command = None
         self._configfile = None
+        self._port_usb = IntVar()
+        self._port_uart1 = IntVar()
+        self._port_uart2 = IntVar()
+        self._port_i2c = IntVar()
+        self._port_spi = IntVar()
+        self._ports = self.__app.frm_settings.defaultports.upper()
         self._body()
         self._do_layout()
         self._attach_events()
@@ -137,7 +153,7 @@ class UBX_PRESET_Frame(Frame):
             self,
             border=2,
             relief="sunken",
-            height=11,
+            height=12,
             width=34,
             justify=LEFT,
             exportselection=False,
@@ -155,6 +171,11 @@ class UBX_PRESET_Frame(Frame):
             width=50,
             command=self._on_send_preset,
         )
+        self._chk_usb = Checkbutton(self, text="USB", variable=self._port_usb)
+        self._chk_uart1 = Checkbutton(self, text="UART1", variable=self._port_uart1)
+        self._chk_uart2 = Checkbutton(self, text="UART2", variable=self._port_uart2)
+        self._chk_i2c = Checkbutton(self, text="I2C", variable=self._port_i2c)
+        self._chk_spi = Checkbutton(self, text="SPI", variable=self._port_spi)
 
     def _do_layout(self):
         """
@@ -167,12 +188,13 @@ class UBX_PRESET_Frame(Frame):
         )
         self._scr_presetv.grid(column=2, row=1, rowspan=12, sticky=(N, S, E))
         self._scr_preseth.grid(column=0, row=13, columnspan=3, sticky=(W, E))
-        self._btn_send_command.grid(
-            column=3, row=1, rowspan=6, ipadx=3, ipady=3, sticky=(E)
-        )
-        self._lbl_send_command.grid(
-            column=4, row=1, rowspan=6, ipadx=3, ipady=3, sticky=(E)
-        )
+        self._btn_send_command.grid(column=3, row=1, ipadx=3, ipady=3, sticky=E)
+        self._lbl_send_command.grid(column=4, row=1, ipadx=3, ipady=3, sticky=E)
+        self._chk_usb.grid(column=3, row=2, columnspan=2, sticky=W)
+        self._chk_uart1.grid(column=3, row=3, columnspan=2, sticky=W)
+        self._chk_uart2.grid(column=3, row=4, columnspan=2, sticky=W)
+        self._chk_i2c.grid(column=3, row=5, columnspan=2, sticky=W)
+        self._chk_spi.grid(column=3, row=6, columnspan=2, sticky=W)
 
         (cols, rows) = self.grid_size()
         for i in range(cols):
@@ -187,12 +209,21 @@ class UBX_PRESET_Frame(Frame):
         """
 
         self._lbx_preset.bind("<<ListboxSelect>>", self._on_select_preset)
+        for prt in ("usb", "uart1", "uart2", "i2c", "spi"):
+            getattr(self, f"_port_{prt}").trace_add(
+                ("write", "unset"), self._on_select_port
+            )
 
     def reset(self):
         """
         Reset panel - Load user-defined presets if there are any.
         """
 
+        self._port_usb.set("USB" in self._ports)
+        self._port_uart1.set("UART1" in self._ports)
+        self._port_uart2.set("UART2" in self._ports)
+        self._port_i2c.set("I2C" in self._ports)
+        self._port_spi.set("SPI" in self._ports)
         idx = 0
         for pst in PRESET_COMMMANDS:
             self._lbx_preset.insert(idx, pst)
@@ -202,6 +233,18 @@ class UBX_PRESET_Frame(Frame):
             self._lbx_preset.insert(idx, "USER " + upst)
             idx += 1
 
+    def _on_select_port(self, var, index, mode):  # pylint: disable=unused-argument
+        """
+        Port has been selected.
+        """
+
+        ports = ""
+        for prt in ("usb", "uart1", "uart2", "i2c", "spi"):
+            if getattr(self, f"_port_{prt}").get():
+                ports += prt.upper() + ","
+        ports = ports.strip(",")
+        self.__app.frm_settings.defaultports = ports
+
     def _on_select_preset(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
         Preset command has been selected.
@@ -222,6 +265,12 @@ class UBX_PRESET_Frame(Frame):
                 status = self._do_factory_reset()
             elif self._preset_command == PSTSAVE:
                 status = self._do_store_config()
+            elif self._preset_command == PSTUSEUBX:
+                self._do_set_allnmea(0)
+                self._do_set_minNAV()
+            elif self._preset_command == PSTUSENMEA:
+                self._do_set_allNAV(0)
+                self._do_set_minnmea()
             elif self._preset_command == PSTMINNMEAON:
                 self._do_set_minnmea()
             elif self._preset_command == PSTALLNMEAON:
@@ -250,6 +299,10 @@ class UBX_PRESET_Frame(Frame):
                 self._do_set_rxm(4)
             elif self._preset_command == PSTALLRXMOFF:
                 self._do_set_rxm(0)
+            elif self._preset_command == PSTALLSECON:
+                self._do_set_sec(1)
+            elif self._preset_command == PSTALLSECOFF:
+                self._do_set_sec(0)
             elif self._preset_command == PSTPOLLPORT:
                 self._do_poll_prt()
             elif self._preset_command == PSTPOLLINFO:
@@ -391,6 +444,17 @@ class UBX_PRESET_Frame(Frame):
             if msgtype[0:1] == b"\x02":
                 self._do_cfgmsg(msgtype, msgrate)
 
+    def _do_set_sec(self, msgrate):
+        """
+        Turn on all device security messages SEC.
+
+        :param int msgrate: message rate (i.e. every nth position solution)
+        """
+
+        for msgtype in UBX_MSGIDS:
+            if msgtype[0:1] == b"\x27":
+                self._do_cfgmsg(msgtype, msgrate)
+
     def _do_set_minnmea(self):
         """
         Turn on minimum set of NMEA messages (GGA & GSA & GSV).
@@ -398,7 +462,7 @@ class UBX_PRESET_Frame(Frame):
 
         for msgtype in UBX_MSGIDS:
             if msgtype[0:1] == b"\xf0":  # standard NMEA
-                if msgtype in (b"\xf0\x00", b"\xf0\x02"):  # GGA, GSA
+                if msgtype in (b"\xf0\x00", b"\xf0\x02", b"\xf0\x04"):  # GGA, GSA, RMC
                     self._do_cfgmsg(msgtype, 1)
                 elif msgtype == b"\xf0\x03":  # GSV
                     self._do_cfgmsg(msgtype, 4)
@@ -459,10 +523,11 @@ class UBX_PRESET_Frame(Frame):
 
         # select which receiver ports to apply rate to
         rates = {}
-        prts = self.__app.frm_settings.config.get(
-            "defaultport_s",
-            self.__app.frm_settings.config.get("defaultport", RCVR_CONNECTION),
-        ).split(",")
+        prts = (
+            self.__app.frm_settings.config.get("defaultport_s", RCVR_CONNECTION)
+            .upper()
+            .split(",")
+        )
         for prt in prts:
             rates[prt] = msgrate
 
